@@ -21,22 +21,25 @@ require 'redmine'
 Redmine::Plugin.register :redmine_local_avatars do
   name 'Redmine Local Avatars plugin'
   author 'Andrew Chaika and Luca Pireddu'
+  author_url 'https://github.com/ncoders/redmine_local_avatars'
   description 'This plugin lets users upload avatars directly into Redmine'
-  version '1.0.5'
+  version '1.0.6'
 end
 
 receiver = Object.const_defined?('ActiveSupport::Reloader') ?  ActiveSupport::Reloader : ActionDispatch::Callbacks
 receiver.to_prepare  do
-	require_dependency 'project'
-	require_dependency 'principal'
-	require_dependency 'user'
+  require_dependency 'project'
+  require_dependency 'principal'
+  require_dependency 'user'
 
-	AccountController.send(:include,  LocalAvatarsPlugin::AccountControllerPatch)
-	ApplicationHelper.send(:include,  LocalAvatarsPlugin::ApplicationAvatarPatch)
-	MyController.send(:include,  LocalAvatarsPlugin::MyControllerPatch)
-	User.send(:include,  LocalAvatarsPlugin::UsersAvatarPatch)
-	UsersController.send(:include,  LocalAvatarsPlugin::UsersControllerPatch)
-	UsersHelper.send(:include,  LocalAvatarsPlugin::UsersHelperPatch)
+  helper_klass = ApplicationHelper.method_defined?(:avatar) ? ApplicationHelper : AvatarsHelper
+
+  AccountController.send(:include,  LocalAvatarsPlugin::AccountControllerPatch)
+  helper_klass.send(:include,  LocalAvatarsPlugin::ApplicationAvatarPatch)
+  MyController.send(:include,  LocalAvatarsPlugin::MyControllerPatch)
+  User.send(:include,  LocalAvatarsPlugin::UsersAvatarPatch)
+  UsersController.send(:include,  LocalAvatarsPlugin::UsersControllerPatch)
+  UsersHelper.send(:include,  LocalAvatarsPlugin::UsersHelperPatch)
 end
 
 require 'local_avatars'
